@@ -27,6 +27,7 @@ random.seed(0)
 
 
 def _rotate_array(data, rotation, offset):
+
     # Create the pixel indices
     az = np.arange(data.shape[0])
     ay = np.arange(data.shape[1])
@@ -64,6 +65,7 @@ def _rotate_array(data, rotation, offset):
 
 
 def _process_sub_tomo(args):
+
     sub_tomo, position, orientation, half_index = args
 
     # Set the data to transform
@@ -89,10 +91,10 @@ def _iterate_particles(
     size,
     half_length,
     half_shape,
-    voxel_size,
     tomogram,
 ):
-    for j in range(len(indices)):
+
+    for j in range(2):
         for i in indices[j]:
             position = positions[i]
             orientation = orientations[i]
@@ -111,39 +113,15 @@ def _iterate_particles(
             )
 
             # Set the region to extract
-            x0 = np.floor(p / voxel_size).astype("int32") - half_length
-            x1 = np.floor(p / voxel_size).astype("int32") + half_length
+            x0 = np.floor(p).astype("int32") - half_length
+            x1 = np.floor(p).astype("int32") + half_length
             offset = p - np.floor(p).astype("int32")
 
             # Get the sub tomogram
             print("Getting sub tomogram")
             sub_tomo = tomogram[x0[1] : x1[1], x0[2] : x1[2], x0[0] : x1[0]]
-            if sub_tomo.shape == half_shape[-3:]:
-                print("YIELD")
-                yield (sub_tomo, offset, orientation, j)
-
-
-def lazy_map(executor, func, iterable):
-    """
-    A lazy map function for concurrent processes
-
-    """
-    max_workers = executor._max_workers
-
-    futures = []
-    for it in iterable:
-        futures.append(executor.submit(func, it))
-        while len(futures) >= max_workers:
-            temp = []
-            for f in futures:
-                if f.done():
-                    yield f.result()
-                else:
-                    temp.append(f)
-            futures = temp
-
-    for future in concurrent.futures.as_completed(futures):
-        yield future.result()
+            if sub_tomo.shape == half_shape[1:]:
+                yield (sub_tomo, position, orientation, j)
 
 
 @singledispatch
@@ -191,7 +169,7 @@ def average_particles(
     )
 
 
-@average_particles.register(parakeet.config.Scan)
+@average_particles.register
 def _average_particles_Config(
     config: parakeet.config.Scan,
     sample: parakeet.sample.Sample,
@@ -207,7 +185,7 @@ def _average_particles_Config(
     """
 
     # Get the scan dict
-    # scan = config.dict()
+    scan = config.dict()
 
     # Get the sample centre
     centre = np.array(sample.centre)
@@ -224,13 +202,12 @@ def _average_particles_Config(
             tomo_file.voxel_size["z"],
         )
     )
-    assert voxel_size[0] == voxel_size[1]
-    assert voxel_size[0] == voxel_size[2]
     size = np.array(tomogram.shape)[[2, 0, 1]] * voxel_size
 
     # Loop through the
     assert sample.number_of_molecules == 1
     for name, (atoms, positions, orientations) in sample.iter_molecules():
+
         # Compute the box size based on the size of the particle so that any
         # orientation should fit within the box
         xmin = atoms.data["x"].min()
@@ -245,15 +222,7 @@ def _average_particles_Config(
 
         if particle_size == 0:
             half_length = (
-                int(
-                    ceil(
-                        sqrt(
-                            ((xmin - xc) / voxel_size[0]) ** 2
-                            + ((ymin - yc) / voxel_size[1]) ** 2
-                            + ((zmin - zc) / voxel_size[2]) ** 2
-                        )
-                    )
-                )
+                int(ceil(sqrt((xmin - xc) ** 2 + (ymin - yc) ** 2 + (zmin - zc) ** 2)))
                 + 1
             )
         else:
@@ -282,9 +251,8 @@ def _average_particles_Config(
         indices = [indices[: num_particles // 2], indices[num_particles // 2 :]]
 
         # Loop through all the particles
-        with concurrent.futures.ProcessPoolExecutor(max_workers=4) as executor:
-            for half_index, data in lazy_map(
-                executor,
+        with concurrent.futures.ProcessPoolExecutor(max_workers=10) as executor:
+            for half_index, data in executor.map(
                 _process_sub_tomo,
                 _iterate_particles(
                     indices,
@@ -294,10 +262,10 @@ def _average_particles_Config(
                     size,
                     half_length,
                     half.shape,
-                    voxel_size,
                     tomogram,
                 ),
             ):
+
                 # Add the contribution to the average
                 half[half_index, :, :, :] += data
                 num[half_index] += 1
@@ -360,7 +328,7 @@ def average_all_particles(
     )
 
 
-@average_all_particles.register(parakeet.config.Scan)
+@average_all_particles.register
 def _average_all_particles_Config(
     config: parakeet.config.Scan,
     sample: parakeet.sample.Sample,
@@ -374,6 +342,7 @@ def _average_all_particles_Config(
     """
 
     def rotate_array(data, rotation, offset):
+
         # Create the pixel indices
         az = np.arange(data.shape[0])
         ay = np.arange(data.shape[1])
@@ -427,13 +396,12 @@ def _average_all_particles_Config(
             tomo_file.voxel_size["z"],
         )
     )
-    assert voxel_size[0] == voxel_size[1]
-    assert voxel_size[0] == voxel_size[2]
     size = np.array(tomogram.shape)[[2, 0, 1]] * voxel_size
 
     # Loop through the
     assert sample.number_of_molecules == 1
     for name, (atoms, positions, orientations) in sample.iter_molecules():
+
         # Compute the box size based on the size of the particle so that any
         # orientation should fit within the box
         xmin = atoms.data["x"].min()
@@ -448,15 +416,7 @@ def _average_all_particles_Config(
 
         if particle_size == 0:
             half_length = (
-                int(
-                    ceil(
-                        sqrt(
-                            ((xmin - xc) / voxel_size[0]) ** 2
-                            + ((ymin - yc) / voxel_size[1]) ** 2
-                            + ((zmin - zc) / voxel_size[2]) ** 2
-                        )
-                    )
-                )
+                int(ceil(sqrt((xmin - xc) ** 2 + (ymin - yc) ** 2 + (zmin - zc) ** 2)))
                 + 1
             )
         else:
@@ -477,34 +437,52 @@ def _average_all_particles_Config(
             *sorted(zip(positions, orientations), key=lambda x: x[0][1])
         )
 
-        # Get the random indices
-        indices = [list(range(len(positions)))]
-
         # Loop through all the particles
-        with concurrent.futures.ProcessPoolExecutor(max_workers=4) as executor:
-            for half_index, data in lazy_map(
-                executor,
-                _process_sub_tomo,
-                _iterate_particles(
-                    indices,
-                    positions,
-                    orientations,
-                    centre,
-                    size,
-                    half_length,
-                    average.shape,
-                    voxel_size,
-                    tomogram,
-                ),
-            ):
+        for i, (position, orientation) in enumerate(zip(positions, orientations)):
+
+            # Compute p within the volume
+            start_position = np.array([0, scan["start_pos"], 0])
+            p = position - (centre - size / 2.0)  # - start_position
+            p[2] = size[2] - p[2]
+            print(
+                "Particle %d: position = %s, orientation = %s"
+                % (
+                    i,
+                    "[ %.1f, %.1f, %.1f ]" % tuple(p),
+                    "[ %.1f, %.1f, %.1f ]" % tuple(orientation),
+                )
+            )
+
+            # Set the region to extract
+            x0 = np.floor(p).astype("int32") - half_length
+            x1 = np.floor(p).astype("int32") + half_length
+            offset = p - np.floor(p).astype("int32")
+
+            # Get the sub tomogram
+            print("Getting sub tomogram")
+            sub_tomo = tomogram[x0[1] : x1[1], x0[2] : x1[2], x0[0] : x1[0]]
+            if sub_tomo.shape == average.shape:
+
+                # Set the data to transform
+                data = sub_tomo
+
+                # Reorder input vectors
+                offset = np.array(data.shape)[::-1] / 2 + offset[[1, 2, 0]]
+                rotation = -np.array(orientation)[[1, 2, 0]]
+                rotation[1] = -rotation[1]
+
+                # Rotate the data
+                print("Rotating volume")
+                data = rotate_array(data, rotation, offset)
+
                 # Add the contribution to the average
+
                 average += data
                 num += 1
 
         # Average the sub tomograms
         print("Averaging map with %d particles" % num)
-        if num > 0:
-            average = average / num
+        average = average / num
 
         # from matplotlib import pylab
         # pylab.imshow(average[half_length, :, :])
