@@ -22,9 +22,7 @@ from parakeet.microscope import Microscope
 from parakeet.scan import Scan
 from functools import singledispatch
 from parakeet.simulate.simulation import Simulation
-
-
-Device = parakeet.config.Device
+from parakeet.config import Device
 
 
 __all__ = ["image"]
@@ -45,20 +43,13 @@ class ImageSimulator(object):
     """
 
     def __init__(
-        self,
-        microscope=None,
-        optics=None,
-        scan=None,
-        simulation=None,
-        device="gpu",
-        gpu_id=None,
+        self, microscope=None, optics=None, scan=None, simulation=None, device="gpu"
     ):
         self.microscope = microscope
         self.optics = optics
         self.scan = scan
         self.simulation = simulation
         self.device = device
-        self.gpu_id = gpu_id
 
     def __call__(self, index):
         """
@@ -75,29 +66,32 @@ class ImageSimulator(object):
 
         # Get the rotation angle
         angle = self.scan.angles[index]
-        exposure_time = self.scan.exposure_time[index]
-        electrons_per_angstrom = self.scan.electrons_per_angstrom[index]
-        if exposure_time <= 0:
-            exposure_time = 1.0
+        position = self.scan.positions[index]
 
         # Check the angle and position
-        assert abs(angle - self.optics.header[index]["tilt_alpha"]) < 1e7
+        assert abs(angle - self.optics.angle[index]) < 1e7
+        assert (np.abs(position - self.optics.position[index]) < 1e7).all()
 
         # Get the specimen atoms
         logger.info(f"Simulating image {index+1}")
 
         # Compute the number of counts per pixel
         electrons_per_pixel = (
-            electrons_per_angstrom * self.microscope.detector.pixel_size**2
+            self.microscope.beam.electrons_per_angstrom
+            * self.microscope.detector.pixel_size**2
         )
 
         # Compute the electrons per pixel second
-        electrons_per_second = electrons_per_pixel / exposure_time
+        electrons_per_second = electrons_per_pixel / self.scan.exposure_time
         energy = self.microscope.beam.energy
 
         # Get the image
         image = self.optics.data[index]
 
+        # Get some other properties to propagate
+        beam_drift = self.optics.drift[index]
+        defocus = self.optics.defocus[index]
+
         # Apply the dqe in Fourier space
         if self.microscope.detector.dqe:
             logger.info("Applying DQE")
@@ -122,23 +116,17 @@ class ImageSimulator(object):
             % (np.min(image), np.max(image), np.mean(image))
         )
 
-        # Get the image metadata
-        metadata = np.asarray(self.optics.header[index])
-        metadata["dose"] = electrons_per_angstrom
-        metadata["dqe"] = self.microscope.detector.dqe
-        metadata["gain"] = 1
-        metadata["offset"] = 0
-
         # Compute the image scaled with Poisson noise
-        return (index, image.astype("float32"), metadata)
+        return (index, angle, position, image.astype("float32"), beam_drift, defocus)
 
 
 def simulation_factory(
     microscope: Microscope,
     optics: object,
     scan: Scan,
+    device: Device = Device.gpu,
     simulation: dict = None,
-    multiprocessing: dict = None,
+    cluster: dict = None,
 ) -> Simulation:
     """
     Create the simulation
@@ -147,32 +135,27 @@ def simulation_factory(
         microscope (object); The microscope object
         optics (object): The optics object
         scan (object): The scan object
+        device (str): The device to use
         simulation (object): The simulation parameters
-        multiprocessing (object): The multiprocessing parameters
+        cluster (object): The cluster parameters
 
     Returns:
         object: The simulation object
 
     """
-    # Check multiprocessing settings
-    if multiprocessing is None:
-        multiprocessing = {"device": "gpu", "nproc": 1, "gpu_id": 0}
-    else:
-        assert multiprocessing["nproc"] in [None, 1]
-        assert len(multiprocessing["gpu_id"]) == 1
 
     # Create the simulation
     return Simulation(
         image_size=(microscope.detector.nx, microscope.detector.ny),
         pixel_size=microscope.detector.pixel_size,
         scan=scan,
+        cluster=cluster,
         simulate_image=ImageSimulator(
             microscope=microscope,
             optics=optics,
             scan=scan,
             simulation=simulation,
-            device=multiprocessing["device"],
-            gpu_id=multiprocessing["gpu_id"][0],
+            device=device,
         ),
     )
 
@@ -199,7 +182,7 @@ def image(config_file, optics_file: str, image_file: str):
     _image_Config(config, optics_file, image_file)
 
 
-@image.register(parakeet.config.Config)
+@image.register
 def _image_Config(config: parakeet.config.Config, optics_file: str, image_file: str):
     """
     Simulate the image with noise
@@ -219,22 +202,18 @@ def _image_Config(config: parakeet.config.Config, optics_file: str, image_file:
     optics = parakeet.io.open(optics_file)
 
     # Create the scan
-    scan = optics.header.scan
-
-    # Override the dose
-    scan_new = parakeet.scan.new(
-        electrons_per_angstrom=microscope.beam.electrons_per_angstrom,
-        **config.scan.dict(),
-    )
-    scan.data["electrons_per_angstrom"] = scan_new.electrons_per_angstrom
+    config.scan.angles = optics.angle
+    config.scan.positions = optics.position[:, 1]
+    scan = parakeet.scan.new(**config.scan.dict())
 
     # Create the simulation
     simulation = simulation_factory(
         microscope=microscope,
         optics=optics,
         scan=scan,
+        device=config.device,
         simulation=config.simulation.dict(),
-        multiprocessing=config.multiprocessing.dict(),
+        cluster=config.cluster.dict(),
     )
 
     # Create the writer
