@@ -20,12 +20,13 @@ import parakeet.futures
 import parakeet.inelastic
 import parakeet.io
 import parakeet.sample
-from parakeet.config import Device
 from parakeet.microscope import Microscope
 from parakeet.scan import Scan
 from functools import singledispatch
-from math import sqrt
+from math import sqrt, pi, sin
 from parakeet.simulate.simulation import Simulation
+from parakeet.config import Device
+from parakeet.config import ClusterMethod
 
 
 __all__ = ["optics"]
@@ -60,7 +61,6 @@ class OpticsImageSimulator(object):
         simulation=None,
         sample=None,
         device="gpu",
-        gpu_id=None,
     ):
         self.microscope = microscope
         self.exit_wave = exit_wave
@@ -68,7 +68,6 @@ class OpticsImageSimulator(object):
         self.simulation = simulation
         self.sample = sample
         self.device = device
-        self.gpu_id = gpu_id
 
     def __call__(self, index):
         """
@@ -83,21 +82,48 @@ class OpticsImageSimulator(object):
 
         """
 
+        def get_defocus(index, angle):
+            """
+            Get the defocus
+
+            Returns:
+                float: defocus
+            """
+
+            defocus = self.microscope.lens.c_10
+            drift = 0
+            defocus_drift = self.microscope.beam.defocus_drift
+            if defocus_drift and not defocus_drift["type"] is None:
+                if defocus_drift["type"] == "random":
+                    drift = np.random.normal(0, defocus_drift["magnitude"])
+                elif defocus_drift["type"] == "random_smoothed":
+                    if index == 0:
+
+                        def generate_smoothed_random(magnitude, num_images):
+                            drift = np.random.normal(0, magnitude, size=(num_images))
+                            drift = np.convolve(drift, np.ones(5) / 5, mode="same")
+                            return drift
+
+                        self._defocus_drift = generate_smoothed_random(
+                            defocus_drift["magnitude"], len(self.scan)
+                        )
+                    drift = self._defocus_drift[index]
+                elif defocus_drift["type"] == "sinusoidal":
+                    drift = sin(angle * pi / 180) * defocus_drift["magnitude"]
+                else:
+                    raise RuntimeError("Unknown drift type")
+                logger.info("Adding defocus drift of %f" % (drift))
+
+            # Return the defocus
+            return defocus + drift
+
         def compute_image(
-            psi,
-            microscope,
-            simulation,
-            x_fov,
-            y_fov,
-            offset,
-            device,
-            gpu_id,
-            defocus=None,
+            psi, microscope, simulation, x_fov, y_fov, offset, device, defocus=None
         ):
+
             # Create the multem system configuration
             system_conf = parakeet.simulate.simulation.create_system_configuration(
-                device,
-                gpu_id,
+                device
             )
 
             # Set the defocus
@@ -117,14 +143,6 @@ class OpticsImageSimulator(object):
             # Compute and apply the CTF
             ctf = np.array(multem.compute_ctf(system_conf, input_multislice)).T
 
-            # Add the effect of the phase plate
-            if microscope.phase_plate.use:
-                ctf = ctf * parakeet.simulate.phase_plate.compute_phase_shift(
-                    ctf.shape,
-                    microscope.detector.pixel_size,
-                    microscope.phase_plate.phase_shift,
-                    microscope.phase_plate.radius,
-                )
             # Compute the B factor for radiation damage
             # if simulation["radiation_damage_model"]:
             #    sigma_B = sqrt(
@@ -149,10 +167,11 @@ class OpticsImageSimulator(object):
 
         # Get the rotation angle
         angle = self.scan.angles[index]
-        defocus_offset = self.scan.defocus_offset[index]
+        position = self.scan.positions[index]
 
         # Check the angle and position
-        assert abs(angle - self.exit_wave.header[index]["tilt_alpha"]) < 1e7
+        assert abs(angle - self.exit_wave.angle[index]) < 1e7
+        assert (np.abs(position - self.exit_wave.position[index]) < 1e7).all()
 
         # The field of view
         nx = self.microscope.detector.nx
@@ -169,16 +188,19 @@ class OpticsImageSimulator(object):
         # Set the input wave
         psi = self.exit_wave.data[index]
 
+        # Get the beam drift
+        driftx, drifty = self.exit_wave.drift[index, :]
+
         microscope = copy.deepcopy(self.microscope)
 
         # Get the defocus
-        defocus = microscope.lens.c_10 + defocus_offset
+        defocus = get_defocus(index, angle)
 
         # If we do CC correction then set spherical aberration and chromatic
         # aberration to zero
         shape = self.sample["shape"]
-        energy_shift = 0
         if self.simulation["inelastic_model"] is None:
+
             # If no inelastic model just calculate image as normal
             image = compute_image(
                 psi,
@@ -188,12 +210,12 @@ class OpticsImageSimulator(object):
                 y_fov,
                 offset,
                 self.device,
-                self.gpu_id,
                 defocus,
             )
             electron_fraction = 1.0
 
         elif self.simulation["inelastic_model"] == "zero_loss":
+
             # Compute the image
             image = compute_image(
                 psi,
@@ -203,7 +225,6 @@ class OpticsImageSimulator(object):
                 y_fov,
                 offset,
                 self.device,
-                self.gpu_id,
                 defocus,
             )
 
@@ -214,6 +235,7 @@ class OpticsImageSimulator(object):
             image *= electron_fraction
 
         elif self.simulation["inelastic_model"] == "mp_loss":
+
             # Set the filter width
             filter_width = self.simulation["mp_loss_width"]  # eV
 
@@ -226,7 +248,7 @@ class OpticsImageSimulator(object):
             # Save the energy and energy spread
             beam_energy = microscope.beam.energy * 1000  # eV
             beam_energy_spread = microscope.beam.energy_spread  # dE / E
-            # beam_energy_sigma = (1.0 / sqrt(2)) * beam_energy_spread * beam_energy  # eV
+            beam_energy_sigma = (1.0 / sqrt(2)) * beam_energy_spread * beam_energy  # eV
 
             # Set a maximum peak energy loss
             peak = min(peak, beam_energy * 0.1)  # eV
@@ -266,7 +288,6 @@ class OpticsImageSimulator(object):
                 y_fov,
                 offset,
                 self.device,
-                self.gpu_id,
                 defocus,
             )
 
@@ -289,13 +310,9 @@ class OpticsImageSimulator(object):
                 y_fov,
                 offset,
                 self.device,
-                self.gpu_id,
                 defocus,
             )
 
-            # Save the energy shift
-            energy_shift = peak
-
             # Compute the zero loss and mpl image fraction
             electron_fraction = elastic_fraction + inelastic_fraction
 
@@ -303,6 +320,7 @@ class OpticsImageSimulator(object):
             image = elastic_fraction * image1 + inelastic_fraction * image2
 
         elif self.simulation["inelastic_model"] == "unfiltered":
+
             # Compute the energy and spread of the plasmon peak
             peak, sigma = parakeet.inelastic.most_probable_loss(
                 microscope.beam.energy, shape, angle
@@ -319,7 +337,6 @@ class OpticsImageSimulator(object):
                 y_fov,
                 offset,
                 self.device,
-                self.gpu_id,
                 defocus,
             )
 
@@ -340,7 +357,6 @@ class OpticsImageSimulator(object):
                 y_fov,
                 offset,
                 self.device,
-                self.gpu_id,
                 defocus,
             )
 
@@ -353,6 +369,7 @@ class OpticsImageSimulator(object):
             image = zero_loss_fraction * image1 + mp_loss_fraction * image2
 
         elif self.simulation["inelastic_model"] == "cc_corrected":
+
             # Set the Cs and CC to zero
             microscope.lens.c_30 = 0
             microscope.lens.c_c = 0
@@ -374,7 +391,6 @@ class OpticsImageSimulator(object):
                 y_fov,
                 offset,
                 self.device,
-                self.gpu_id,
                 defocus,
             )
 
@@ -395,7 +411,6 @@ class OpticsImageSimulator(object):
                 y_fov,
                 offset,
                 self.device,
-                self.gpu_id,
                 defocus,
             )
 
@@ -427,60 +442,18 @@ class OpticsImageSimulator(object):
             % (np.min(image), np.mean(image), np.max(image))
         )
 
-        # Set the metadata
-        metadata = np.asarray(self.exit_wave.header[index])
-        metadata["c_10"] = defocus
-        metadata["c_12"] = self.microscope.lens.c_12
-        metadata["c_21"] = self.microscope.lens.c_21
-        metadata["c_23"] = self.microscope.lens.c_23
-        metadata["c_30"] = self.microscope.lens.c_30
-        metadata["c_32"] = self.microscope.lens.c_32
-        metadata["c_34"] = self.microscope.lens.c_34
-        metadata["c_41"] = self.microscope.lens.c_41
-        metadata["c_43"] = self.microscope.lens.c_43
-        metadata["c_45"] = self.microscope.lens.c_45
-        metadata["c_50"] = self.microscope.lens.c_50
-        metadata["c_52"] = self.microscope.lens.c_52
-        metadata["c_54"] = self.microscope.lens.c_54
-        metadata["c_56"] = self.microscope.lens.c_56
-        metadata["phi_12"] = self.microscope.lens.phi_12
-        metadata["phi_21"] = self.microscope.lens.phi_21
-        metadata["phi_23"] = self.microscope.lens.phi_23
-        metadata["phi_32"] = self.microscope.lens.phi_32
-        metadata["phi_34"] = self.microscope.lens.phi_34
-        metadata["phi_41"] = self.microscope.lens.phi_41
-        metadata["phi_43"] = self.microscope.lens.phi_43
-        metadata["phi_45"] = self.microscope.lens.phi_45
-        metadata["phi_52"] = self.microscope.lens.phi_52
-        metadata["phi_54"] = self.microscope.lens.phi_54
-        metadata["phi_56"] = self.microscope.lens.phi_56
-        metadata["c_c"] = self.microscope.lens.c_c
-        metadata["current_spread"] = self.microscope.lens.current_spread
-        metadata["illumination_semiangle"] = self.microscope.beam.illumination_semiangle
-        metadata[
-            "acceleration_voltage_spread"
-        ] = self.microscope.beam.acceleration_voltage_spread
-        metadata["energy_spread"] = self.microscope.beam.energy_spread
-        metadata["phase_plate"] = self.microscope.phase_plate
-        metadata["inelastic_model"] = self.simulation["inelastic_model"]
-        metadata["slit_inserted"] = self.simulation["inelastic_model"] in [
-            "zero_loss",
-            "mp_loss",
-        ]
-        metadata["slit_width"] = self.simulation["mp_loss_width"]
-        metadata["energy_shift"] = energy_shift
-
         # Compute the image scaled with Poisson noise
-        return (index, image, metadata)
+        return (index, angle, position, image, (driftx, drifty), defocus)
 
 
 def simulation_factory(
     microscope: Microscope,
     exit_wave: object,
     scan: Scan,
+    device: Device = Device.gpu,
     simulation: dict = None,
     sample: dict = None,
-    multiprocessing: dict = None,
+    cluster: dict = None,
 ) -> Simulation:
     """
     Create the simulation
@@ -489,34 +462,28 @@ def simulation_factory(
         microscope (object); The microscope object
         exit_wave (object): The exit_wave object
         scan (object): The scan object
+        device (str): The device to use
         simulation (object): The simulation parameters
-        multiprocessing (object): The multiprocessing parameters
+        cluster (object): The cluster parameters
 
     Returns:
         object: The simulation object
 
     """
 
-    # Check multiprocessing settings
-    if multiprocessing is None:
-        multiprocessing = {"device": "gpu", "nproc": 1, "gpu_id": 0}
-    else:
-        assert multiprocessing["nproc"] in [None, 1]
-        assert len(multiprocessing["gpu_id"]) == 1
-
     # Create the simulation
     return Simulation(
         image_size=(microscope.detector.nx, microscope.detector.ny),
         pixel_size=microscope.detector.pixel_size,
         scan=scan,
+        cluster=cluster,
         simulate_image=OpticsImageSimulator(
             microscope=microscope,
             exit_wave=exit_wave,
             scan=scan,
             simulation=simulation,
             sample=sample,
-            device=multiprocessing["device"],
-            gpu_id=multiprocessing["gpu_id"][0],
+            device=device,
         ),
     )
 
@@ -526,9 +493,9 @@ def optics(
     config_file,
     exit_wave_file: str,
     optics_file: str,
-    device: Device = None,
-    nproc: int = None,
-    gpu_id: list = None,
+    device: Device = Device.gpu,
+    cluster_method: ClusterMethod = None,
+    cluster_max_workers: int = 1,
 ):
     """
     Simulate the optics
@@ -537,22 +504,22 @@ def optics(
         config_file: The input config filename
         exit_wave_file: The input exit wave filename
         optics_file: The output optics filename
-        device: The device to run on (cpu or gpu)
-        nproc: The number of processes
-        gpu_id: The list of gpu ids
+        device: The device to run on (CPU or GPU)
+        cluster_method: The cluster method to use (default None)
+        cluster_max_workers: The maximum number of cluster jobs
 
     """
 
     # Load the full configuration
     config = parakeet.config.load(config_file)
 
-    # Set the command line args in a dict
+    # Set the device in a dict
     if device is not None:
-        config.multiprocessing.device = device
-    if nproc is not None:
-        config.multiprocessing.nproc = nproc
-    if gpu_id is not None:
-        config.multiprocessing.gpu_id = gpu_id
+        config.device = device
+    if cluster_max_workers is not None:
+        config.cluster.max_workers = cluster_max_workers
+    if cluster_method is not None:
+        config.cluster.method = cluster_method
 
     # Print some options
     parakeet.config.show(config)
@@ -561,7 +528,7 @@ def optics(
     _optics_Config(config, exit_wave_file, optics_file)
 
 
-@optics.register(parakeet.config.Config)
+@optics.register
 def _optics_Config(
     config: parakeet.config.Config, exit_wave_file: str, optics_file: str
 ):
@@ -583,20 +550,19 @@ def _optics_Config(
     exit_wave = parakeet.io.open(exit_wave_file)
 
     # Create the scan
-    scan = exit_wave.header.scan
-
-    # Override the defocus_offset
-    scan_new = parakeet.scan.new(**config.scan.dict())
-    scan.data["defocus_offset"] = scan_new.defocus_offset
+    config.scan.angles = exit_wave.angle
+    config.scan.positions = exit_wave.position[:, 1]
+    scan = parakeet.scan.new(**config.scan.dict())
 
     # Create the simulation
     simulation = simulation_factory(
         microscope,
         exit_wave,
         scan,
+        device=config.device,
         simulation=config.simulation.dict(),
         sample=config.sample.dict(),
-        multiprocessing=config.multiprocessing.dict(),
+        cluster=config.cluster.dict(),
     )
 
     # Create the writer
