@@ -19,14 +19,14 @@ import parakeet.freeze
 import parakeet.futures
 import parakeet.inelastic
 import parakeet.sample
-from parakeet.config import Device
-from parakeet.sample import Sample
 from parakeet.microscope import Microscope
+from parakeet.sample import Sample
 from parakeet.scan import Scan
 from parakeet.simulate.simulation import Simulation
 from functools import singledispatch
 from math import pi, floor
-from scipy.spatial.transform import Rotation as R
+from parakeet.config import Device
+from parakeet.config import ClusterMethod
 
 
 __all__ = ["potential"]
@@ -35,7 +35,6 @@ __all__ = ["potential"]
 # Get the logger
 logger = logging.getLogger(__name__)
 
-
 # Try to input MULTEM
 try:
     import multem
@@ -61,7 +60,6 @@ class ProjectedPotentialSimulator(object):
         scan=None,
         simulation=None,
         device="gpu",
-        gpu_id=None,
     ):
         self.potential_prefix = potential_prefix
         self.microscope = microscope
@@ -69,7 +67,6 @@ class ProjectedPotentialSimulator(object):
         self.scan = scan
         self.simulation = simulation
         self.device = device
-        self.gpu_id = gpu_id
 
     def __call__(self, index):
         """
@@ -86,12 +83,7 @@ class ProjectedPotentialSimulator(object):
 
         # Get the rotation angle
         angle = self.scan.angles[index]
-        position = self.scan.position[index]
-        orientation = self.scan.orientation[index]
-        shift = self.scan.shift[index]
-        drift = self.scan.shift_delta[index]
-        beam_tilt_theta = self.scan.beam_tilt_theta[index]
-        beam_tilt_phi = self.scan.beam_tilt_phi[index]
+        position = self.scan.positions[index]
 
         # The field of view
         nx = self.microscope.detector.nx
@@ -111,8 +103,7 @@ class ProjectedPotentialSimulator(object):
 
         # Create the multem system configuration
         system_conf = parakeet.simulate.simulation.create_system_configuration(
-            self.device,
-            self.gpu_id,
+            self.device
         )
 
         # The Z centre
@@ -142,9 +133,9 @@ class ProjectedPotentialSimulator(object):
         if len(atoms.data) > 0:
             coords = atoms.data[["x", "y", "z"]].to_numpy()
             coords = (
-                R.from_rotvec(orientation).apply(coords - self.sample.centre)
+                self.scan.poses.orientations[index].apply(coords - self.sample.centre)
                 + self.sample.centre
-                - position
+                - self.scan.poses.shifts[index]
             ).astype("float32")
             atoms.data["x"] = coords[:, 0]
             atoms.data["y"] = coords[:, 1]
@@ -184,7 +175,7 @@ class ProjectedPotentialSimulator(object):
         multem.compute_projected_potential(system_conf, input_multislice, callback)
 
         # Compute the image scaled with Poisson noise
-        return (index, None, None)
+        return (index, angle, position, None, None, None)
 
 
 def simulation_factory(
@@ -192,8 +183,9 @@ def simulation_factory(
     microscope: Microscope,
     sample: Sample,
     scan: Scan,
+    device: Device = Device.gpu,
     simulation: dict = None,
-    multiprocessing: dict = None,
+    cluster: dict = None,
 ) -> Simulation:
     """
     Create the simulation
@@ -203,8 +195,9 @@ def simulation_factory(
         microscope: The microscope object
         sample: The sample object
         scan: The scan object
+        device: The device to use
         simulation: The simulation parameters
-        multiprocessing (object): The multiprocessing parameters
+        cluster: The cluster parameters
 
     Returns:
         object: The simulation object
@@ -213,13 +206,6 @@ def simulation_factory(
     # Get the margin
     margin = 0 if simulation is None else simulation.get("margin", 0)
 
-    # Check multiprocessing settings
-    if multiprocessing is None:
-        multiprocessing = {"device": "gpu", "nproc": 1, "gpu_id": 0}
-    else:
-        assert multiprocessing["nproc"] in [None, 1]
-        assert len(multiprocessing["gpu_id"]) == 1
-
     # Create the simulation
     return Simulation(
         image_size=(
@@ -228,14 +214,14 @@ def simulation_factory(
         ),
         pixel_size=microscope.detector.pixel_size,
         scan=scan,
+        cluster=cluster,
         simulate_image=ProjectedPotentialSimulator(
             potential_prefix=potential_prefix,
             microscope=microscope,
             sample=sample,
             scan=scan,
             simulation=simulation,
-            device=multiprocessing["device"],
-            gpu_id=multiprocessing["gpu_id"][0],
+            device=device,
         ),
     )
 
@@ -245,9 +231,9 @@ def potential(
     config_file,
     sample_file: str,
     potential_prefix: str,
-    device: Device = None,
-    nproc: int = None,
-    gpu_id: list = None,
+    device: Device = Device.gpu,
+    cluster_method: ClusterMethod = None,
+    cluster_max_workers: int = 1,
 ):
     """
     Simulate the projected potential from the sample
@@ -256,9 +242,9 @@ def potential(
         config_file: The input config filename
         sample_file: The input sample filename
         potential_prefix: The input potential filename
-        device: The device to run on (cpu or gpu)
-        nproc: The number of processes
-        gpu_id: The list of gpu ids
+        device: The device to run on (CPU or GPU)
+        cluster_method: The cluster method to use (default None)
+        cluster_max_workers: The maximum number of cluster jobs
 
     """
 
@@ -267,11 +253,11 @@ def potential(
 
     # Set the command line args in a dict
     if device is not None:
-        config.multiprocessing.device = device
-    if nproc is not None:
-        config.multiprocessing.nproc = nproc
-    if gpu_id is not None:
-        config.multiprocessing.gpu_id = gpu_id
+        config.device = device
+    if cluster_max_workers is not None:
+        config.cluster.max_workers = cluster_max_workers
+    if cluster_method is not None:
+        config.cluster.method = cluster_method
 
     # Print some options
     parakeet.config.show(config)
@@ -280,7 +266,7 @@ def potential(
     _potential_Config(config, sample_file, potential_prefix)
 
 
-@potential.register(parakeet.config.Config)
+@potential.register
 def _potential_Config(
     config: parakeet.config.Config, sample_file: str, potential_prefix: str
 ):
@@ -305,10 +291,7 @@ def _potential_Config(
     if config.scan.step_pos == "auto":
         radius = sample.shape_radius
         config.scan.step_pos = config.scan.step_angle * radius * pi / 180.0
-    scan = parakeet.scan.new(
-        electrons_per_angstrom=microscope.beam.electrons_per_angstrom,
-        **config.scan.dict(),
-    )
+    scan = parakeet.scan.new(**config.scan.dict())
 
     # Create the simulation
     simulation = simulation_factory(
@@ -316,8 +299,9 @@ def _potential_Config(
         microscope=microscope,
         sample=sample,
         scan=scan,
+        device=config.device,
         simulation=config.simulation.dict(),
-        multiprocessing=config.multiprocessing.dict(),
+        cluster=config.cluster.dict(),
     )
 
     # Run the simulation
